# -*- coding: utf-8 -*-
# Copyright 2023 Cohesity Inc.

class TypeUdaProtectionSourceEnum(object):

    """Implementation of the 'TypeUdaProtectionSource' enum.
    Specifies the type of the managed Object in Universal Data Adapter
    Protection Source. Specifies the type of an Universal Data Adapter source
    entity. 'kCluster' indicates a Universal Data Adapter source, possibly
    distributed over several physical nodes. 'kObject' indicates a generic
    object within the UDA environment.


    Attributes:
        KCLUSTER: TODO: type description here.
        KOBJECT: TODO: type description here.

    """

    KCLUSTER = 'kCluster'

    KOBJECT = 'kObject'
